@@ -1,17 +1,16 @@
-# Calc command.
+"""$ rio calc"""
 
+from collections import OrderedDict
 from distutils.version import LooseVersion
-import logging
 
 import click
 import snuggs
-from cligj import files_inout_arg
 
-from .helpers import resolve_inout
-from . import options
 import rasterio
-from rasterio.fill import fillnodata
 from rasterio.features import sieve
+from rasterio.fill import fillnodata
+from rasterio.rio import options
+from rasterio.rio.helpers import resolve_inout
 
 
 def get_bands(inputs, d, i=None):
@@ -32,7 +31,7 @@ def read_array(ix, subix=None, dtype=None):
 
 @click.command(short_help="Raster data calculator.")
 @click.argument('command')
-@files_inout_arg
+@options.files_inout_arg
 @options.output_opt
 @click.option('--name', multiple=True,
               help='Specify an input file with a unique short (alphas only) '
@@ -40,10 +39,10 @@ def read_array(ix, subix=None, dtype=None):
                    '"a=tests/data/RGB.byte.tif".')
 @options.dtype_opt
 @options.masked_opt
-@options.force_overwrite_opt
+@options.overwrite_opt
 @options.creation_options
 @click.pass_context
-def calc(ctx, command, files, output, name, dtype, masked, force_overwrite,
+def calc(ctx, command, files, output, name, dtype, masked, overwrite,
          creation_options):
     """A raster data calculator
 
@@ -86,12 +85,10 @@ def calc(ctx, command, files, output, name, dtype, masked, force_overwrite,
     """
     import numpy as np
 
-    verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
-
     try:
-        with rasterio.Env(CPL_DEBUG=verbosity > 2):
+        with ctx.obj['env']:
             output, files = resolve_inout(files=files, output=output,
-                                          force_overwrite=force_overwrite)
+                                          overwrite=overwrite)
 
             inputs = ([tuple(n.split('=')) for n in name] +
                       [(None, n) for n in files])
@@ -99,11 +96,10 @@ def calc(ctx, command, files, output, name, dtype, masked, force_overwrite,
             with rasterio.open(inputs[0][1]) as first:
                 kwargs = first.meta
                 kwargs.update(**creation_options)
-                kwargs['transform'] = kwargs.pop('affine')
                 dtype = dtype or first.meta['dtype']
                 kwargs['dtype'] = dtype
 
-            ctxkwds = {}
+            ctxkwds = OrderedDict()
             for i, (name, path) in enumerate(inputs):
                 with rasterio.open(path) as src:
                     # Using the class method instead of instance
@@ -123,7 +119,7 @@ def calc(ctx, command, files, output, name, dtype, masked, force_overwrite,
             snuggs.func_map['fillnodata'] = lambda *args: fillnodata(*args)
             snuggs.func_map['sieve'] = lambda *args: sieve(*args)
 
-            res = snuggs.eval(command, **ctxkwds)
+            res = snuggs.eval(command, ctxkwds)
 
             if (isinstance(res, np.ma.core.MaskedArray) and (
                     tuple(LooseVersion(np.__version__).version) < (1, 9) or
